@@ -1,3 +1,6 @@
+#ifndef XCHAT_NOTIFY_H
+#define XCHAT_NOTIFY_H
+
 struct notify
 {
 	char *name;
@@ -10,7 +13,7 @@ struct notify_per_server
 	time_t laston;
 	time_t lastseen;
 	time_t lastoff;
-	int ison:1;
+	unsigned int ison:1;
 };
 
 extern GSList *notify_list;
@@ -29,7 +32,10 @@ void notify_load (void);
 void notify_save (void);
 void notify_showlist (session *sess);
 int notify_isnotify (session *sess, char *name);
+struct notify_per_server *notify_find_server_entry (struct notify *notify, struct server *serv);
 
 /* the old ISON stuff - remove me? */
 void notify_markonline (server *serv, char *word[]);
 int notify_checklist (void);
+
+#endif
