@@ -39,6 +39,7 @@
 #include "../common/xchat.h"
 #include "../common/notify.h"
 #include "../common/cfgfiles.h"
+#include "../common/fe.h"
 #include "../common/util.h"
 #include "../common/userlist.h"
 #include "gtkutil.h"
@@ -290,8 +291,8 @@ notify_opengui (void)
 	}
 
 	notify_window =
-		mg_create_generic_tab ("notify", _("X-Chat: Notify List"), FALSE, TRUE,
-		                       notify_closegui, NULL, 400, 120, &vbox, 0);
+		mg_create_generic_tab ("Notify", _("XChat: Notify List"), FALSE, TRUE,
+		                       notify_closegui, NULL, 400, 250, &vbox, 0);
 
 	view = notify_treeview_new (vbox);
 	g_object_set_data (G_OBJECT (notify_window), "view", view);
@@ -304,7 +305,7 @@ notify_opengui (void)
 
 	gtkutil_button (bbox, GTK_STOCK_NEW, 0, notify_add_clicked, 0,
 	                _("Add"));
-	gtkutil_button (bbox, GTK_STOCK_CLOSE, 0, notify_remove_clicked, 0,
+	gtkutil_button (bbox, GTK_STOCK_DELETE, 0, notify_remove_clicked, 0,
 	                _("Remove"));
 
 	notify_gui_update ();
